### {{ character|safe }} / {{ ship|safe }}

__**Request Details:**__
**Character:** {{ character|safe }}
**Ship:** {{ ship|safe }}
**SRP Code:** {{ srp_code }}
**SRP Link:** {{ srp_link }}
**Request Code:** {{ request_code }}
**zKillboard Link:** {{ killboard_link }}
{% if additional_info %}
__**Additional Information:**__
{{ additional_info|safe }}
{% endif %}
