# Generated by Django 4.2.8 on 2023-12-11 22:11

# Django
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("aasrp", "0012_alter_fleettype_options_alter_insurance_options_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="setting",
            name="loss_value_source",
            field=models.CharField(
                choices=[
                    ("fittedValue", "Fitted value (Ship and Fitting)"),
                    ("totalValue", "Total value (Ship, Fitting and Cargo)"),
                ],
                default="totalValue",
                help_text="The source for the loss value of a killmail. Fitted value is the value of the ship and its fitting. Total value is the value of the ship, its fitting and the cargo. (Default: Total value)",
                max_length=11,
                verbose_name="Loss value source",
            ),
        ),
    ]
