{% load django_bootstrap5 %}
{% load i18n %}

<div class="card card-default">
    <div class="card-header">
        <div class="card-title mb-0">
            {% translate "After action report" %}
        </div>
    </div>

    <div class="card-body">
        <form action="{% url 'aasrp:edit_srp_link' srp_code %}" method="post">
            {% csrf_token %}

            <fieldset class="aa-srp-edit-link-form col-md-6 col-md-offset-3">
                {% bootstrap_form form %}

                <div class="form-group aasrp-form-group text-end clearfix">
                    {% translate "Add/Change AAR link" as button_text %}
                    {% bootstrap_button button_class="btn btn-primary" button_type="submit" content=button_text %}
                </div>
            </fieldset>
        </form>
    </div>
</div>
