{% load i18n %}

<!-- enable srp link -->
<div class="modal fade" id="enable-srp-link" tabindex="-1" role="dialog" aria-labelledby="{% translate 'Enable SRP link' %}" aria-hidden="true">
    <div class="modal-dialog modal-dialog-centered" role="document">
        <div class="modal-content">
            <div class="modal-header">
                <div class="modal-title fs-5">
                    {% translate "Enable SRP link" %}
                </div>

                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="{% translate 'Close' %}"></button>
            </div>

            <div class="modal-body"></div>

            <div class="modal-footer">
                <button type="button" class="btn btn-secondary btn-sm" data-bs-dismiss="modal">
                    <i class="fa-regular fa-hand"></i>
                    {% translate "Cancel" %}
                </button>

                <a id="modal-button-confirm-enable-srp-link" class="btn btn-success btn-sm" role="button" href="">
                    <i class="fa-solid fa-check"></i>
                    {% translate "Enable" %}
                </a>
            </div>
        </div>
    </div>
</div>
