<span class="copy-to-clipboard-icon">
    <i
        class="copy-to-clipboard fa-regular fa-copy ms-2 cursor-pointer"
        data-clipboard-text="{{ data }}"
        data-bs-tooltip="aa-srp"
        aria-label="{{ title }}"
        title="{{ title }}"
    ></i>
</span>
